Re: [PATCH v2 0/2] do_compare_entry: use already-computed path
- From
David Turner <dturner@twopensource.com>
- Date
- Dec 22, 2015, 04:26 UTC
- Message-ID
- <1450758362.3892.7.camel@twopensource.com>
- In-Reply-To
- <CAPc5daW4ru0j4Zd3ynnRcG8df7sZ9ZuVHu8mz2rxVonZpyE4Gw@mail.gmail.com>
On Mon, 2015-12-21 at 15:34 -0800, Junio C Hamano wrote:
Show 9 quoted lines
> Great. Thanks, will queue w/o 1/2 (though I do not think it would > hurt). > > On Mon, Dec 21, 2015 at 3:33 PM, David Turner < > dturner@twopensource.com> wrote: > > On Mon, 2015-12-21 at 15:27 -0800, Junio C Hamano wrote: > > > Thanks. Does the number still stay at 25% improvement? > > > > Yes.
BTW, that function, via ce_in_traverse_path, gets called about 40 million times when switching (checking out) between master and a branch that's a few months old (and that contains relatively small changes from master-as-of-then. Our repo only has approximately a quarter -million files. This seems somewhat unreasonable to me, but I haven't really looked into what's going on. Do you happen to know why this is and whether it is likely to be a bug?